import Taro, { Component } from '@tarojs/taro';
import './index.scss'
import AchievePhone from '@/components/achievePhone'
import AchieveAvatar from '@/components/achieveAvatar'
import { connect } from '@tarojs/redux'
import ready from '@/utils/ready'
import { queryHouseDetail } from '@/services/project'
import dayjs from 'dayjs'
import { transferImage } from '@/utils/tools'
import Blank from '../../components/Blank'

@connect(
  ({ user }) => ({ ...user })
)

export default class Index extends Component {
  config = {
    navigationBarTitleText: '房源详情',
  }

  state = {
    grantPhoneVisible: false, // 授权电话
    grantAvatarVisible: false, // 授权头像
    houseDetail: null,
    popVisiable: false,
  }


  componentDidShow() {

    ready.queue(() => {
      // 分享场景需要先授权手机, 再授权头像
      if (this.toggleGrantPhone()) {
        this.toggleGrantAvatar()
      }
      const id = this.$router.params.id
      const { userInfo: { person: { personId } } } = this.props
      const params = {
        houseId: id,
        personId,
      }
      queryHouseDetail(params).then(res => {
        this.setState({
          houseDetail: res || {},
          buildingImgList: res.buildingImgList || []
        })
      })

    })
  }



  // 调起授权电话
  toggleGrantPhone = () => {
    const { userInfo: { person: { phone, tel } } } = this.props
    if (!phone && !tel) {
      this.setState({ grantPhoneVisible: true })
      return false
    }
    console.log('phone:', phone, 'tel:', tel, '!!!!!')
    console.log(this.props, 'this.propsphone!!!!!')

    return true
  }

  // 调起授权头像
  toggleGrantAvatar = () => {
    const { userInfo: { person: { avatarurl } } } = this.props

    if (!avatarurl || avatarurl.indexOf('wx.qlogo.cn') === -1) {
      this.setState({ grantAvatarVisible: true })
      return false
    }

    console.log(avatarurl, "avatarurl")
    console.log(this.props.userInfo, "this.props")
    return true
  }

  chooseBtn(type) {
    const { houseDetail: { houseId, buildingId } } = this.state
    Taro.navigateTo({
      url: `/onlineSelling/pages/detail/resultPage?type=${type}&id=${houseId}&buildingId=${buildingId}`
    })
    this.setState({ popVisiable: false })
  }


  handleChat(buildingId) {
    Taro.navigateTo({
      url: `/pages/card/list/index?buildingId=${buildingId}`
    })
  }


  render() {
    const { grantPhoneVisible, grantAvatarVisible, houseDetail, buildingImgList, popVisiable } = this.state
    const { userInfo } = this.props
    const address = `${houseDetail.buildingName || ''}${houseDetail.termName || ''}${houseDetail.blockName || ''}${houseDetail.unitName || ''}${houseDetail.floorName || ''}${houseDetail.roomName || ''}`

    return (
      <Block>
        {
          grantPhoneVisible &&
          <AchievePhone user={userInfo.person} onSuccess={this.toggleGrantAvatar}></AchievePhone>
        }
        {
          grantAvatarVisible &&
          <AchieveAvatar user={userInfo.person} onSuccess={() => { this.setState({ grantAvatarVisible: false }) }} ></AchieveAvatar>
        }
        {popVisiable && <View className="pop-box">
          <View className="title" >{!houseDetail.isPreselect ? `确认使用手机号${userInfo.person.phone || userInfo.person.tel}预选此房源？` : '确认取消预选此房源？'}</View>
          <View className="sure" onClick={!houseDetail.isPreselect ? () => this.chooseBtn('add') : () => this.chooseBtn('cancel')}>确定</View>
          <View className="cancel" onClick={() => this.setState({ popVisiable: false })}>取消</View>
        </View>}

        <View className='detail'>
          <View className='detail-top'>
            {buildingImgList.length ?
              <Image className="cover-img" mode="aspectFill" src={transferImage(buildingImgList[0].url)}></Image>
              : <Blank tips="暂无户型信息"></Blank>
            }

          </View>
          <ScrollView
            enableBackToTop
            className="wrap"
            scrollY>
            <View className='detail__main'>
              <View style="padding: 0 30rpx;">
                <View className="name">{houseDetail.apartmentName || ''}</View>
                <View className="btn" onClick={() => this.handleChat(houseDetail.buildingId)}>询问优惠</View>
                <View className="price">
                  现价：{houseDetail.price}万
              </View>
                {houseDetail.apartmentName &&
                  <View className="area">
                    {houseDetail.buildingArea ? <Text>建筑面积约<Text style="color:#FE1C1C">{houseDetail.buildingArea}</Text>m² </Text> : '建筑面积待定'}
                    <Text style="margin-left:20rpx">{houseDetail.insideArea ? <Text>使用面积约<Text style="color:#FE1C1C">{houseDetail.insideArea}</Text>m² </Text> : '使用面积待定'}</Text>
                  </View>
                }
                <View className="address">
                  <Image className="location-icon" src={require('../../assets/location.png')}></Image>{address || ''}
                </View>
                <View className="date">
                  预选时间：{dayjs(houseDetail.preselectionStartTime).format('MM/DD HH:mm:ss')}--{dayjs(houseDetail.preselectionEndTime).format('MM/DD HH:mm:ss')}
                </View>
                {/* <View className="date">
                  认筹时间：2/12 12:23:33--2/13 12:23:34
              </View> */}
              </View>
              <View className="num">
                已有{houseDetail.realHeat + houseDetail.heat + 0}人预选此房源，快快预选认筹~
              </View>
              <View style="padding: 0 30rpx;">
                {!houseDetail.isPreselect ?
                  <View className="choose-btn" onClick={() => this.setState({ popVisiable: true })}>
                    预选此房源
                  </View> : <View className="choose-btn" onClick={() => this.setState({ popVisiable: true })}>
                    取消预选
                  </View>
                }
                <View className="close-btn">
                  认筹功能未开放
              </View>
              </View>


            </View>
          </ScrollView>



        </View>

      </Block>
    );
  }
}
